@@ -3,11 +3,13 @@ from .renderers import ListRenderers
 from .render import RenderArtifact
 from .s3publish import S3PublishArtifacts
 from .travisprefixgen import TravisPrefixGeneration
+from .test import TestRulebook
 
 __all__ = [
     "Operation",
     "ListRenderers",
     "RenderArtifact",
     "S3PublishArtifacts",
-    "TravisPrefixGeneration"
+    "TravisPrefixGeneration",
+    "TestRulebook"
 ]
